==> haskell-attoparsec-0.13.2.2-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
key: attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
license: BSD3
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
abi: 9d8982f8b70cf41a2e1b007eb9382565
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
    transformers-0.5.2.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG=490d099f5e386f4f486a599d7d1e6789
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-0.13.2.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec
version: 0.13.2.2
id: attoparsec-0.13.2.2-KnkUxVEson3AzYFappLt2D
key: attoparsec-0.13.2.2-KnkUxVEson3AzYFappLt2D
license: BSD-3-Clause
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>, Ben Gamari <ben@smart-cactus.org>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: https://github.com/bos/attoparsec
synopsis: Fast combinator parsing for bytestrings and text
description:
    A fast parser combinator library, aimed particularly at dealing
    efficiently with network protocols and complicated text/binary
    file formats.
category: Text, Parsing
abi: bb3660ce70d29d644cde35d789165619
exposed: True
exposed-modules:
    Data.Attoparsec Data.Attoparsec.ByteString
    Data.Attoparsec.ByteString.Char8 Data.Attoparsec.ByteString.Lazy
    Data.Attoparsec.Char8 Data.Attoparsec.Combinator
    Data.Attoparsec.Internal Data.Attoparsec.Internal.Types
    Data.Attoparsec.Lazy Data.Attoparsec.Number Data.Attoparsec.Text
    Data.Attoparsec.Text.Lazy Data.Attoparsec.Types
    Data.Attoparsec.Zepto
hidden-modules: Data.Attoparsec.ByteString.Buffer
                Data.Attoparsec.ByteString.FastSet
                Data.Attoparsec.ByteString.Internal
                Data.Attoparsec.Internal.Fhthagn Data.Attoparsec.Text.Buffer
                Data.Attoparsec.Text.FastSet Data.Attoparsec.Text.Internal
import-dirs: /usr/lib/ghc-8.4.2/site-local/attoparsec-0.13.2.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/attoparsec-0.13.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/attoparsec-0.13.2.2
hs-libraries: HSattoparsec-0.13.2.2-KnkUxVEson3AzYFappLt2D
depends:
    array-0.5.2.0 base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    deepseq-1.4.3.0 scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8
    transformers-0.5.5.0 text-1.2.3.0
abi-depends: array-0.5.2.0=59560c027ff6ea5b7e467a38c579b575
             base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             bytestring-0.10.8.2=c1695cedf0cebf0c12d34c90fb94a65f
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             deepseq-1.4.3.0=521dff49867cc7581bb7066827d3f18e
             scientific-0.3.6.2-5CyHdegMsTFBY4p5C2C7g8=bf2c4ab253b66175121fc647b8699c7c
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
haddock-interfaces: /usr/share/doc/haskell-attoparsec/html/attoparsec.haddock
haddock-html: /usr/share/doc/haskell-attoparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
